@@ -17,6 +17,7 @@ class InputManager : public QObject
     Q_PROPERTY(QString result READ result NOTIFY resultChanged)
     Q_PROPERTY(QString binaryResult READ binaryResult NOTIFY binaryResultChanged)
     Q_PROPERTY(QString hexResult READ hexResult NOTIFY hexResultChanged)
+    Q_PROPERTY(bool moveFromResult READ moveFromResult NOTIFY resultChanged)
     Q_PROPERTY(bool binaryMode READ binaryMode WRITE setBinaryMode)
 
 public:
@@ -26,6 +27,7 @@ public:
     const QString &result() const;
     const QString &binaryResult() const;
     const QString &hexResult() const;
+    bool moveFromResult() const;
     Q_INVOKABLE void append(const QString &subexpression);
     Q_INVOKABLE void backspace();
     Q_INVOKABLE void equal();
@@ -33,20 +35,27 @@ public:
     Q_INVOKABLE void fromHistory(const QString &result);
     void setBinaryMode(bool active);
     bool binaryMode();
+    QString formatNumbers(const QString &text);
+    void addNumberSeparators(QString &number);
 
 Q_SIGNALS:
     void expressionChanged();
     void resultChanged();
     void binaryResultChanged();
     void hexResultChanged();
+
 private:
     InputManager();
     bool m_moveFromResult = false; // clear expression on none operator input
     std::vector<int> m_stack; // track subexpression length for removal later
+    QString m_input;
+    QString m_output;
     QString m_expression;
     QString m_result;
     QString m_binaryResult;
     QString m_hexResult;
     bool m_isBinaryMode = false; // Changes the parser based on this variable
+    QString m_groupSeparator;
+    QString m_decimalPoint;
 };
 
